<?php declare(strict_types=1);

namespace App\Service;

use App\Entity\Printer;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Serializer\SerializerInterface;

class PrinterService
{
    public function __construct(private readonly EntityManagerInterface $entityManager, private readonly SerializerInterface $serializer)
    {
    }

    public function deletePrinter(Printer $printer): void
    {
        $this->entityManager->remove($printer);
        $this->entityManager->flush();
    }

    public function createPrinter(string $jsonString): Printer
    {
        $printer = $this->serializer->deserialize($jsonString, Printer::class, 'json');
        $this->entityManager->persist($printer);
        $this->entityManager->flush();

        return $printer;
    }

    public function validateJson(string $jsonString): bool
    {
        $array = json_decode($jsonString, true);
        return isset($array['name'], $array['price'], $array['max_speed'], $array['build_volume']);
    }
}